#!/usr/bin/env python
from glob import glob
import re
from os import listdir, path
from sys import argv, exit
from xml.etree import ElementTree as ET

NS = '{http://kpi.fei.tuke.sk/practices}'

NS_PATTERN = re.compile(r'\{.+\}')


def remove_namespaces(root):
    """Remove all namespaces in the passed tree in place."""
    for elem in root.iter():
        elem.tag = NS_PATTERN.sub('', elem.tag)


def extract_quiz(input_filename, output_filename):
    """Extract quiz information from the XML document."""
    tree = ET.parse(input_filename)
    quiz = tree.find('.//%squiz' % NS)
    if quiz is not None:
        print "Store quiz from %s to %s" % (input_filename, output_filename)
        remove_namespaces(quiz)
        with file(output_filename, 'w') as f:
            f.write(ET.tostring(quiz, 'utf-8', 'xml'))


def extract_all_quizzes(input_dir, output_dir):
    """
    Extract quiz information from all practices of all subjects.
    """
    for subject in listdir(input_dir):
        for practice in glob(path.join(input_dir, subject, "??.xml")):
            num = path.splitext(path.basename(practice))[0]
            filename = "%s-%s.xml" % (subject, num)
            extract_quiz(practice, path.join(output_dir, filename))


if __name__ == '__main__':
    if len(argv) < 3:
        print "Usage: %s <input-directory> <output-directory>" % argv[0]
        exit(1)
    extract_all_quizzes(argv[1], argv[2])
