# -*- coding: utf8 -*-

import unittest

from model import Question, Level


class TestQuestion(unittest.TestCase):
    def setUp(self):
        self.question = Question("How?", "Easily")

    def test_right_answer(self):
        self.assertTrue(self.question.check_answer("Easily"))

    def test_wrong_answer(self):
        self.assertFalse(self.question.check_answer("Hardly"))

    def test_normalization(self):
        self.assertTrue(self.question.check_answer(" easily  "))
        self.assertTrue(self.question.check_answer(u"ěásiľy"))


class TestLevel(unittest.TestCase):
    def setUp(self):
        question1 = Question("How?", "Easily")
        question2 = Question("What?", "This")
        self.level = Level([question1, question2])

    def test_right_answers(self):
        answers = ["Easily", "This"]
        self.assertTrue(self.level.check_answers(answers) == 0)

    def test_wrong_answers(self):
        answers = ["Hardly", "That"]
        self.assertTrue(self.level.check_answers(answers) == 2)

    def test_empty_answers(self):
        answers = []
        self.assertTrue(self.level.check_answers(answers) == 2)

    def test_half_wrong_answers(self):
        answers = ["Hardly", "This"]
        self.assertTrue(self.level.check_answers(answers) == 1)
